==> u133x3p.db_2.0.2.tar.gz: u133x3p.db/man/u133x3p_dbconn.Rd <==
\name{u133x3p_dbconn}

\alias{u133x3p_dbconn}
\alias{u133x3p_dbfile}
\alias{u133x3p_dbschema}
\alias{u133x3p_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  u133x3p_dbconn()
  u133x3p_dbfile()
  u133x3p_dbschema(file="", show.indices=FALSE)
  u133x3p_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{u133x3p_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{u133x3p_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{u133x3p_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{u133x3p_dbschema} prints the schema definition of the
  package annotation DB.

  \code{u133x3p_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{u133x3p_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{u133x3p_dbfile}: a character string with the path to the
  package annotation DB.

  \code{u133x3p_dbschema}: none (invisible \code{NULL}).

  \code{u133x3p_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(u133x3p_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by u133x3p_dbconn() was created with:
  dbConnect(SQLite(), dbname=u133x3p_dbfile(), cache_size=64000, synchronous=0)

  u133x3p_dbschema()

  u133x3p_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> u133x3p.db_2.9.0.tar.gz: u133x3p.db/man/u133x3p_dbconn.Rd <==

\name{u133x3p_dbconn}

\alias{u133x3p_dbconn}
\alias{u133x3p_dbfile}
\alias{u133x3p_dbschema}
\alias{u133x3p_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  u133x3p_dbconn()
  u133x3p_dbfile()
  u133x3p_dbschema(file="", show.indices=FALSE)
  u133x3p_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{u133x3p_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{u133x3p_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{u133x3p_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{u133x3p_dbschema} prints the schema definition of the
  package annotation DB.

  \code{u133x3p_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{u133x3p_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{u133x3p_dbfile}: a character string with the path to the
  package annotation DB.

  \code{u133x3p_dbschema}: none (invisible \code{NULL}).

  \code{u133x3p_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(u133x3p_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by u133x3p_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=u133x3p_dbfile(), cache_size=64000,
  synchronous=0)

  u133x3p_dbschema()

  u133x3p_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
